---
gitea: none
include_toc: true
---
# dictionaries/rougail/00-base.yml

```yaml
---
version: '1.1'

leader:
  description: a leadership
  type: leadership

  leader:
    description: a leader
    multi: true
    hidden: true
    mandatory: false

  follower:
    description: a follower
    mandatory: false
```
